"""
Shell Doctest module.

:Copyright: (c) 2009, the Shell Doctest Team All rights reserved.
:license: BSD, see LICENSE for more details.

$ echo TEST
TEST

[#TEST1]
$ echo TEST1
TEST1

[#TEST2]
$ echo TEST2
TEST2
"""
